@@ -2,7 +2,7 @@
 This file is part of the `arabluatex' package
 
 ArabLuaTeX -- Processing ArabTeX notation under LuaLaTeX
-Copyright (C) 2016--2018  Robert Alessi
+Copyright (C) 2016--2020  Robert Alessi
 
 Please send error reports and suggestions for improvements to Robert
 Alessi <alessi@robertalessi.net>
@@ -43,7 +43,7 @@ captr = {
    {a="b", b="B"},
    {a="t", b="T"},
    {a="ṯ", b="Ṯ"},
-   {a="ǧ", b="Ǧ"},
+   {a="ǧ", b="Ǧ"},
    {a="ḥ", b="Ḥ"},
    {a="ḫ", b="Ḫ"},
    {a="d", b="D"},
@@ -75,7 +75,7 @@ lcuc = {
    {a="b", b="B"},
    {a="t", b="T"},
    {a="ṯ", b="Ṯ"},
-   {a="ǧ", b="Ǧ"},
+   {a="ǧ", b="Ǧ"},
    {a="j", b="J"},
    {a="ḥ", b="Ḥ"},
    {a="ḫ", b="Ḫ"},
@@ -427,7 +427,7 @@ digraphstrdmg = {
    {a="T(%p*)$", b="h%1"},
    {a="T(%p*)(%W)", b="h%1%2"},
    {a="_t", b="ṯ"},
-   {a="%^g", b="ǧ"},
+   {a="%^g", b="ǧ"},
    {a="%.h", b="ḥ"},
    {a="_h", b="ḫ"},
    {a="_d", b="ḏ"},
@@ -462,7 +462,7 @@ digraphstrdmg = {
 singletrdmg = {
    {a="b", b="b"},
    {a="t", b="t"},
-   {a="j", b="ǧ"},
+   {a="j", b="ǧ"},
    {a="x", b="ḫ"},
    {a="d", b="d"},
    {a="r", b="r"},
@@ -949,7 +949,7 @@ digraphstrarabica = {
    {a="aT(%p*)$", b="a%1"},
    {a="aT(%p*%s)", b="a%1"},
    {a="_t", b="ṯ"},
-   {a="%^g", b="ǧ"},
+   {a="%^g", b="ǧ"},
    {a="%.h", b="ḥ"},
    {a="_h", b="ḫ"},
    {a="_d", b="ḏ"},
@@ -983,7 +983,7 @@ digraphstrarabica = {
 singletrarabica = {
    {a="b", b="b"},
    {a="t", b="t"},
-   {a="j", b="ǧ"},
+   {a="j", b="ǧ"},
    {a="x", b="ḫ"},
    {a="d", b="d"},
    {a="r", b="r"},
